#--------------------------------------------------------------------------
# Framework Information
#--------------------------------------------------------------------------
# Name of the framework
NAME = "orionis"

# Current version of the framework
VERSION = "0.36.0"

# Full name of the author or maintainer of the project
AUTHOR = "Raul Mauricio Uñate Castro"

# Email address of the author or maintainer for contact purposes
AUTHOR_EMAIL = "raulmauriciounate@gmail.com"

# Short description of the project or framework
DESCRIPTION = "Orionis Framework – Elegant, Fast, and Powerful."

#--------------------------------------------------------------------------
# Project URLs
#--------------------------------------------------------------------------
# URL to the project's skeleton or template repository (for initial setup)
SKELETON = "https://github.com/orionis-framework/skeleton"

# URL to the project's main framework repository
FRAMEWORK = "https://github.com/orionis-framework/framework"

# URL to the project's documentation
DOCS = "https://github.com/orionis-framework/docs"

#--------------------------------------------------------------------------
# Python Requirements
#--------------------------------------------------------------------------
# Minimum Python version required to run the project
PYTHON_REQUIRES = ">=3.12"
